from dataclasses import dataclass, field, asdict


@dataclass
class QuizDTO:
    title: str
    description: str
    quiz_type: str = 'practice_quiz'


@dataclass
class Answer:  # pylint: disable=too-few-public-methods
    """canvas answer see for complete list of (valid) fields
    https://canvas.instructure.com/doc/api/quiz_questions.html#:~:text=An%20Answer-,object,-looks%20like%3A
    """
    answer_html: str
    answer_weight: int


AnswerOptions = dict[str, int]  # answer_text, answer_weigth


# complete list of params : https://canvas.instructure.com/doc/api/quiz_questions.html


@dataclass
class QuestionDTO:
    answers: list[AnswerOptions]
    question_name: str = ""
    question_type: str = 'multiple_choice_question'  # other option is essay question
    question_text: str = ''
    points_possible: str = '1.0'
    correct_comments: str = ''
    incorrect_comments: str = ''
    neutral_comments: str = ''
    correct_comments_html: str = ''
    incorrect_comments_html: str = ''
    neutral_comments_html: str = ''


@dataclass
class Stats:
    quiz_ids: list[int] = field(default_factory=list)
    question_ids: list[int] = field(default_factory=list)


from dataclasses import dataclass
from typing import TypeVar, Generic, List, Dict, Tuple

from .course import Course, EnrollDTO, SearchTextInCourseDTO
from .user import User
from .guest import Guest
from .quiz import Answer, QuizDTO, QuestionDTO, Stats



import typing
import collections
import re
import canvasapi


class Guest:
    def __init__(self,
                 *args, **varg) -> None:
        if args and isinstance(args[0], canvasapi.user.User):
            self.user_id = args[0].id
            self.name = args[0].name
        elif len(args) > 1:
            self.user_id,  # lms user_id
            self.guest_id,  # needed?
            self.username,  # TiU username
            self.anr,
            self.name,
            self.organisation,
            self.start_date,
            self.end_date,
            self.group_id,
            self.status,
            self.memo = args
        elif type(varg) == dict:
            self.__dict__ = varg




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['canvasrobot', 'canvasrobot.entities']

package_data = \
{'': ['*']}

install_requires = \
['canvasapi>=3.0.0,<3.1.0',
 'keyring',
 'openpyxl>=3.0.10,<4.0.0',
 'pyaml>=21.10.1,<22.0.0',
 'pydal>=20220814.1,<20220815.0',
 'requests>=2.28.1,<2.29.0',
 'rich>=12.5.1,<13.0.0',
 'toml']

setup_kwargs = {
    'name': 'canvasrobot',
    'version': '0.1.3',
    'description': '',
    'long_description': 'None',
    'author': 'Nico de Groot',
    'author_email': 'ndegroot0@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
